==> easy-bdd-0.5.3.tgz: package/index.js <==
const low = require("lowdb")
const FileSync = require("lowdb/adapters/FileSync")

function Read(files, get, filterName) {

    const adapter = new FileSync(files)
    const db = low(adapter)

    if(typeof filterName !== "object") return Error("le filter doit être un object")

    const data = db.get(get).filter(filterName).value()

    if(data[0] === undefined) return Error(`data est undefined vérifié l'appel de la function: Read("test.json", "inv", {UserId: "tg"}) `)

    return data[0]

}
//console.log(Read("test.json", "inv", {UserId: "tg"}))

function find(files, get, filterName) {

    const adapter = new FileSync(files)
    const db = low(adapter)

    if(typeof filterName !== "object") return Error("le finder doit être un object")

    const data = db.get(get).find(filterName).value()

    if(data === undefined) return Error(`data est undefined vérifié l'appel de la function: Read("test.json", "inv", {UserId: "tg"}) `)

    return data

}
//console.log(find("test.json", "inv", {UserId: "tg"}))

function push(files, get, push) {

    const adapter = new FileSync(files)
    const db = low(adapter)


    const data = db.get(get).push(push).write()

    if(data === undefined) return Error(`data est undefined vérifié l'appel de la function: Read("test.json", "inv", {UserId: "tg"}) `)

    return data   //console.log(Object.values(db)[0].push({inv: []}))
}
//push("test.json", "inv", {UserId: "ftg", ID: 9, name: "mdr"})

function defaut(files, push) {

    const adapter = new FileSync(files)
    const db = low(adapter)


    const data = db.defaults(push).write()

    if(data === undefined) return Error(`data est undefined vérifié l'appel de la function: Read("test.json", "inv", {UserId: "tg"}) `)


    return data

}
//defaut("test.json", { test: []})

function assign(files, get, filterName, assign) {
    const adapter = new FileSync(files)
    const db = low(adapter)


    if(typeof filterName !== "object") return Error("le finder doit être un object")
    if(typeof assign !== "object") return Error("le assign doit être un object")

    const data = db.get(get).find(filterName).assign(assign).write()

    console.log(typeof assign)
    if(data === undefined) return Error(`data est undefined vérifié l'appel de la function: Read("test.json", "inv", {UserId: "tg"}) `)

    return data

}
//console.log(assign("test.json", "tg", {UserId: "mdr"}, {naame: "test"}))


module.exports = {

    Read,
    find,
    push,
    defaut,
    assign

}

==> easy-bdd-0.5.7.tgz: package/index.js <==
const low = require("lowdb")
const FileSync = require("lowdb/adapters/FileSync")

function Read(files, get, filterName) {

    const adapter = new FileSync(files)
    const db = low(adapter)

    if(typeof filterName !== "object") return Error("le filter doit être un object")

    const data = db.get(get).filter(filterName).value()

    if(data[0] === undefined) return 

    return data[0]

}
//console.log(Read("test.json", "inv", {UserId: "tg"}))

function find(files, get, filterName) {

    const adapter = new FileSync(files)
    const db = low(adapter)

    if(typeof filterName !== "object") return Error("le finder doit être un object")

    const data = db.get(get).find(filterName).value()

    if(data === undefined) return

    return data

}
//console.log(find("test.json", "inv", {name: "holia"}))
//console.log(find("test.json", "inv", {i: "i"}))

function push(files, get, push) {

    const adapter = new FileSync(files)
    const db = low(adapter)


    const data = db.get(get).push(push).write()

    if(data === undefined) return

    return data   //console.log(Object.values(db)[0].push({inv: []}))
}
//push("test.json", "inv", {UserId: "ftg", ID: 9, name: "mdr"})

function defaut(files, push) {

    const adapter = new FileSync(files)
    const db = low(adapter)


    const data = db.defaults(push).write()

    if(data === undefined) return 


    return data

}
//defaut("test.json", { test: []})

function assign(files, get, filterName, assign) {
    const adapter = new FileSync(files)
    const db = low(adapter)


    if(typeof filterName !== "object") return Error("le finder doit être un object")
    if(typeof assign !== "object") return Error("le assign doit être un object")

    const data = db.get(get).find(filterName).assign(assign).write()

    //console.log(typeof assign)
    if(data === undefined) return 

    return data

}
//console.log(assign("test.json", "tg", {UserId: "mdr"}, {naame: "test"}))

/*setTimeout(() => {
    
}, 9999);*/


module.exports = {

    Read,
    find,
    push,
    defaut,
    assign

}
